;; Generated package description from keymap-popup.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "keymap-popup" "0.2.6.0.20260506.238" "Described keymaps with popup help" '((emacs "29.1")) :commit "4130d1fa958eeff2d677ad1e326b18ddb77bebb4" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("convenience") :url "https://codeberg.org/thanosapollo/emacs-keymap-popup")
